@@ -1,7 +1,7 @@
 package Log::ger::Util;
 
-our $DATE = '2017-06-25'; # DATE
-our $VERSION = '0.007'; # VERSION
+our $DATE = '2017-06-26'; # DATE
+our $VERSION = '0.008'; # VERSION
 
 use strict;
 use warnings;
@@ -41,6 +41,18 @@ sub numeric_level {
     die "Unknown level '$level'";
 }
 
+sub string_level {
+    my $level = shift;
+    return $level if defined $Log::ger::Levels{$level};
+    $level = $Log::ger::Level_Aliases{$level}
+        if defined $Log::ger::Level_Aliases{$level};
+    for (keys %Log::ger::Levels) {
+        my $v = $Log::ger::Levels{$_};
+        return $_ if $v == $level;
+    }
+    die "Unknown level '$level'";
+}
+
 sub set_level {
     no warnings 'once';
     $Log::ger::Current_Level = numeric_level(shift);
@@ -222,7 +234,7 @@ Log::ger::Util - Utility routines for Log::ger
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 DESCRIPTION
 
